Learn R Programming

funest (version 0.0.1.3)

funest_fit: Fitting functional ensemble survival tree model

Description

The function funest_fit takes a long and a short form of the survival data, among other arguments for a random survival forest, to fit an functional ensemble survival tree model for predicting survival probability.

Usage

funest_fit(
  long_train,
  surv_train,
  noftree = 500,
  nofcov = 2,
  split_rule = "maxstat",
  tv_names,
  fv_names,
  nofp = 3,
  t_star,
  t_pred,
  ...
)

Arguments

long_train

long form of survival data from the training set

surv_train

short form of survival data from the training set

noftree

number of trees in the random survival forest

nofcov

number of covariates selected in each survival tree

split_rule

binary splitting rule for random survival forest, default is "maxstat"

tv_names

a list of names of time-varying covariates

fv_names

a list of names of fixed covariates

nofp

number of multivariate principal components

t_star

time for the last observed biomarker measurement

t_pred

time at prediction

...

extra arguments that can be passed to ranger()

Value

A list compose two items. The first item is a list of necessary information for prediction used in funest_pred() function. The second item is the ranger object of the fitted random survival forest.

  • misc - a list composed of 1) long_train: long form of survival data from the training set, 2) surv_train: short form of survival data from the training set, 3) fmla: covariates passed into the ensemble survival tree 4) score_names: intermediate names for the covariates 5) nofp: number of multivariate principal components 6) train_data.sub: data frame of all covariates after MFPCA been performed

  • rg - functional ensemble survival tree model

References

nestpaperfunest

rangerfunest

Examples

Run this code
# NOT RUN {
library(funest)
data("long_train")
data("surv_train")
w = funest_fit(long_train, surv_train, tv_names = list("Y1", "Y2", "Y3"), fv_names = list("W"),
 noftree = 10, t_star = 5.5, t_pred = 11)
# }

Run the code above in your browser using DataLab